"use strict";
/**
 * @fileoverview Storybook's main config should use a default export format
 * @author Yann Braga
 */
const ast_1 = require("../utils/ast");
const constants_1 = require("../utils/constants");
const create_storybook_rule_1 = require("../utils/create-storybook-rule");
module.exports = (0, create_storybook_rule_1.createStorybookRule)({
    name: 'default-export-in-main',
    defaultOptions: [],
    meta: {
        type: 'problem',
        docs: {
            description: 'Main config should use a default export format',
            categories: [constants_1.CategoryId.CSF_STRICT],
            recommended: 'error',
            isMainConfigRule: true,
        },
        messages: {
            shouldUseDefaultExport: 'Your main config should use a default export format.',
        },
        schema: [],
    },
    create(context) {
        let hasDefaultExport = false;
        //----------------------------------------------------------------------
        // Helpers
        //----------------------------------------------------------------------
        //----------------------------------------------------------------------
        // Public
        //----------------------------------------------------------------------
        return {
            ExportDefaultDeclaration: function () {
                hasDefaultExport = true;
            },
            'Program:exit': function (program) {
                const firstNonImportStatement = program.body.find((n) => !(0, ast_1.isImportDeclaration)(n));
                const node = firstNonImportStatement || program.body[0] || program;
                if (!hasDefaultExport) {
                    context.report({
                        node,
                        messageId: 'shouldUseDefaultExport',
                    });
                }
            },
        };
    },
});
